@@ -178,7 +178,6 @@ class MainInterface:
         if self.rangeOn.get():
             s = int(self.firstFrame.get())
             e = int(self.lastFrame.get())
-            print(s, e)
             save_values(s, e)
             if e < len(frames_in) - 1:
                 load_frame(e + 1, master, self.fbox)
@@ -327,6 +326,7 @@ def load_folder(project_name):
     configure(project_name)
     curr_target_csv= os.path.join(os.path.dirname(project_name),'csv','targets_inserted',os.path.basename(img_dir)+'.csv')
     df = pd.read_csv(curr_target_csv)
+    df = df.fillna(0)
 
     ##load last saved frames
     try:
@@ -394,14 +394,22 @@ def set_values(dictionary):
 
 # Saves the values of each behavior in the DataFrame and prints out the updated data frame
 def save_values(start, end):
+    global columns
+    contprintLoop = True
+    print('\n')
     if start == end:
         for i in range(len(behaviors)):
             df.at[current_frame_number, columns[i]] = int(behaviors[i])
+            if behaviors[i] != 0:
+                print('Annotated behavior: ' + columns[i] + '. Frame: ' + str(start) + '.')
+
     if start != end:
         for i in range(start, end+1):
             for b in range(len(behaviors)):
                 df.at[i, columns[b]] = int(behaviors[b])
-    print(df.ix[current_frame_number])
+                if behaviors[b] != 0 and (contprintLoop == True):
+                    print('Annotated behavior: ' + columns[b] + '. Start frame: ' + str(start) + '. End frame: ' + str(end))
+            contprintLoop = False
 
 
 # Appends data to corresponding features_extracted csv and exports as new csv
